#!/bin/bash
#
# createNode.sh - create a new TeamCall CSTAServer node under Linux
#                 (supports Debian, Suse and Ubuntu distributions)
#
# Copyright (c) 2006, 2010-2011, 2017 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
#


SCRIPT_NAME="createNode.sh"
PATH=$PATH:/usr/bin:/usr/sbin:/sbin


# Check for root permissions
perm=$(id -u)
if [ "$perm" != "0" ]; then
    echo "You must be root to run this script"
    echo "Creating TeamCall CSTAServer node canceled"
    exit 1
fi


# Path of TeamCall directory e.g. /usr/local/ilink/teamcall
cd $(dirname "$0")
TCSPATH=$(pwd | sed -e s%/bin%%g)
#echo "TCSPATH -> $TCSPATH"
cd - > /dev/null


# Check library dependencies for CSTAServer binary
# FIXME: also check for existing 32 bit support on 64 bit systems
libdep=$(ldd "$TCSPATH"/bin/CSTAServer | grep "not found")
if [ "X$libdep" !=  "X" ]; then
	echo ""
	echo "Required libraries for CSTAServer not found"
	echo "Missing libraries:"
	echo "$libdep"
	echo ""
	exit 1
fi


# Default variables
NODENAME="ilink"
PBXTYPE="?"


# Determine Linux distribution
DIST="unknown"
if [ "`lsb_release -i | grep -i debian`" ]; then
	DIST="debian"
elif [ "`lsb_release -i | grep -i suse`" ]; then
	DIST="suse"
elif [ "`lsb_release -i | grep -i ubuntu`" ]; then
	DIST="ubuntu"
else
	echo "Distribution not supported!"
	echo "($SCRIPT_NAME only supports Debian, Suse and Ubuntu distributions)"
	exit 0
fi


# Get and confirm all parameters
while [ "$checkParameters" != "OK" ]
do
	clear
	echo "Creating a new TeamCall node"
	echo ""

	echo -e "Node name of the new TeamCall CSTAServer instance [$NODENAME]:\c "
	read NODENAME_TMP

	if [ "$NODENAME_TMP" != "" ]; then
   	   NODENAME="$NODENAME_TMP"
	fi

	echo -e "PBX type ("?" show PBX types) [$PBXTYPE]:\c "
	read PBXTYPE_TMP
	
	if [ "$PBXTYPE_TMP" != "" ]; then
   		PBXTYPE="$PBXTYPE_TMP"
	fi

	while [ "$PBXTYPE" = "?" ]
	do
		if [ "$PBXTYPE" = "?" ]; then
			"$TCSPATH"/bin/CSTAServer --list | grep "pbx" | sed -e 's/ *-pbx//'
		fi		

		echo -e "PBX Type [$PBXTYPE]:\c "
		read PBXTYPE_TMP
		if [ "$PBXTYPE_TMP" != "" ]; then
   	   		PBXTYPE="$PBXTYPE_TMP"
		fi
	done

	echo "----------------------------------------------------------"
	echo " Review the settings:"
	echo ""
	echo " New TeamCall CSTAServer node: $NODENAME"
	echo " PBX type:                     $PBXTYPE"
	echo ""
	echo "----------------------------------------------------------"

	checker="0"	
	echo -e "Are these settings correct? Then type OK: \c"
	read checker

	if [ "$checker" = "OK" ];then
   	   checkParameters="OK"
	fi
done


# Set owner and permission of TeamCall directory
chown -R root:root "$TCSPATH"


# Check for existence of the node
if [ -d "$TCSPATH/node_$NODENAME" ];then
	echo
	echo "The node $NODENAME already exists!"
	echo "Can't create this node!"
	echo ""
	exit -1
fi


# Create directory structure
mkdir "$TCSPATH/node_$NODENAME"
mkdir "$TCSPATH/node_$NODENAME"/init_scripts
mkdir "$TCSPATH/node_$NODENAME"/log
mkdir "$TCSPATH/node_$NODENAME"/run
echo "Directory structure '$TCSPATH/node_$NODENAME' created ..."


# Create executable links
ln -s "$TCSPATH"/bin/CSTAServer "$TCSPATH/node_$NODENAME/CSTAServer_$NODENAME"
echo "Executable links created in '$TCSPATH/node_$NODENAME' ..."


# Copy or parse templates to node directory
sed -e  's&'%%NODE%%'&'$NODENAME'&g'       \
    -e  's&'%%PBX%%'&'$PBXTYPE'&g'         \
    -e  's&'%%TCINSTALL%%'&'$TCSPATH'&g'   \
         "$TCSPATH"/templates/CSTAServer_XYZ > "$TCSPATH/node_$NODENAME/init_scripts/CSTAServer_$NODENAME"
chmod a+x "$TCSPATH/node_$NODENAME/init_scripts/CSTAServer_$NODENAME"
cp "$TCSPATH"/templates/Default.conf  "$TCSPATH/node_$NODENAME/"
cp "$TCSPATH"/templates/DialPlan.conf "$TCSPATH/node_$NODENAME/"
chmod u=rw,go=r "$TCSPATH/node_$NODENAME"/*.conf
echo "Files copied and parsed ..."


# Create init links (distribution specific)
ln -s "$TCSPATH/node_$NODENAME/init_scripts/CSTAServer_$NODENAME" /etc/init.d/CSTAServer_"$NODENAME"

if [ "$DIST" = "debian" -o "$DIST" = "ubuntu" ]; then
	update-rc.d "CSTAServer_$NODENAME" defaults > /dev/null 2>&1
fi
if [ "$DIST" = "suse" ]; then
	chkconfig --add "CSTAServer_$NODENAME" > /dev/null 2>&1
fi
echo "Start/stop links created ..."

